summaryrefslogtreecommitdiff
path: root/src/gpm-kbd-backlight.c
diff options
context:
space:
mode:
Diffstat (limited to 'src/gpm-kbd-backlight.c')
-rw-r--r--src/gpm-kbd-backlight.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/gpm-kbd-backlight.c b/src/gpm-kbd-backlight.c
index 8c8ba69..4ed3fcf 100644
--- a/src/gpm-kbd-backlight.c
+++ b/src/gpm-kbd-backlight.c
@@ -31,7 +31,7 @@
static const gchar *kbd_backlight_introspection = ""
"<?xml version=\"1.0\" encoding=\"UTF-8\"?>""<node name=\"/\">"
- "<interface name=\"org.gnome.PowerManager.Backlight\">"
+ "<interface name=\"org.mate.PowerManager.Backlight\">"
"<method name=\"GetBrightness\">"
"<arg type=\"u\" name=\"percentage_brightness\" direction=\"out\"/>"
"</method>"
@@ -489,7 +489,7 @@ gpm_kbd_backlight_button_pressed_cb (GpmButton *button,
* @mode: The idle mode, e.g. GPM_IDLE_MODE_BLANK
* @backlight: This class instance
*
* This callback is called when gnome-screensaver detects that the idle state
* has changed. GPM_IDLE_MODE_BLANK is when the session has become inactive,
* and GPM_IDLE_MODE_SLEEP is where the session has become inactive, AND the
* session timeout has elapsed for the idle action.
@@ -489,7 +489,7 @@ gpm_kbd_backlight_button_pressed_cb (GpmButton *button,
* @backlight: This class instance
*
- * This callback is called when gnome-screensaver detects that the idle state
+ * This callback is called when mate-screensaver detects that the idle state
* has changed. GPM_IDLE_MODE_BLANK is when the session has become inactive,
* and GPM_IDLE_MODE_SLEEP is where the session has become inactive, AND the